### Path Analysis for Chris' data
##### Load libraries #####
library(piecewiseSEM)
library(nlme)


##### Load data #####
collard=read.delim("collard_data.csv", sep=",")
tomato=read.delim("tomato_data.csv", sep=",")
strawberry=read.delim("strawberry_data.csv", sep=",")
squash=read.delim("squash_data.csv", sep=",")

#### Collard Path Model ####
### Initial model with pests predicting total yield (unexpected positive effect)
coll.mod=psem(
  lme(tnipred~Year+Field_Treatment_bin+Natural_25+Natural_5+Natural_1,random=~1|Field/Plant, data=collard,na.action=na.omit),
  lme(wormlog~Year+tnipred+Natural_25+Natural_5+Total_leaves,data=collard, random=~1|Field/Plant,na.action=na.omit),
  lme(dbmlog~Year+tnipred+Total_leaves,data=collard, random=~1|Field/Plant,na.action=na.omit),
  lme(Prop_leaves_market~Year+dbmlog+wormlog+Natural_25,random=~1|Field/Plant, data=collard,na.action=na.omit),
  lme(Total_leaves~Year+dbmlog+wormlog,random=~1|Field/Plant, data=collard,na.action=na.omit),
  wormlog%~~%dbmlog, Prop_leaves_market%~~%Total_leaves,
  Natural_25%~~%Natural_5, Natural_5%~~%Natural_1, Natural_25%~~%Natural_1
)

summary(coll.mod, conserve=T)

#compare to model where total yield predicts pest
coll.mod2=psem(
  lme(tnipred~Year+Field_Treatment_bin+Natural_25+Natural_5+Natural_1,random=~1|Field/Plant, data=collard,na.action=na.omit),
  lme(wormlog~Year+tnipred+Natural_25+Natural_5+Total_leaves,data=collard, random=~1|Field/Plant,na.action=na.omit),
  lme(dbmlog~Year+Total_leaves,data=collard, random=~1|Field/Plant,na.action=na.omit),
  lme(Prop_leaves_market~Year+dbmlog+wormlog+Natural_25,random=~1|Field/Plant, data=collard,na.action=na.omit),
  wormlog%~~%dbmlog, Prop_leaves_market%~~%Total_leaves,
  Natural_25%~~%Natural_5, Natural_5%~~%Natural_1, Natural_25%~~%Natural_1
)

AIC(coll.mod, coll.mod2)
#path model with yield as predictor is much better

summary(coll.mod2)

##### Tomato Path Model #####
tom.mod=psem(
  lme(hzpred~Year+Natural_25+Natural_5+Natural_1, random=~1|Field/Plant, data=tomato,na.action=na.omit),
  lme(sbpred~Year+Natural_25+Natural_5+Natural_1, random=~1|Field/Plant, data=tomato,na.action=na.omit),
  lme(armlog~Year+hzpred+sbpred,data=tomato, random=~1|Field/Plant,na.action=na.omit),
  lme(manlog~Year+hzpred+sbpred,data=tomato, random=~1|Field/Plant,na.action=na.omit),
  lme(prop_damaged_chew~Year+manlog+Field_Treatment_bin*Natural_25,data=tomato, random=~1|Field/Plant,na.action=na.omit),
  lme(prop_damaged_suck~Year+Natural_25,data=tomato, random=~1|Field/Plant,na.action=na.omit),
  lme(Prop_fruit_market~Year+manlog+prop_damaged_chew+prop_damaged_suck,random=~1|Field/Plant, data=tomato,na.action=na.omit),
  lme(Total_fruit~Year+prop_damaged_chew+Field_Treatment_bin,random=~1|Field/Plant, data=tomato,na.action=na.omit),
  hzpred%~~%sbpred, Prop_fruit_market%~~%Total_fruit,prop_damaged_chew%~~%prop_damaged_suck,
  Natural_25%~~%Natural_5, Natural_5%~~%Natural_1, Natural_25%~~%Natural_1
)

summary(tom.mod, conserve=T)

#### Strawberry Path Model ####
strw.mod=psem(
  lme(PollinationRatio~Year+Natural_25+Natural_5+Natural_1, random=~1|Field/Plant, data=strawberry,na.action=na.omit),
  lme(prop_damaged_lygus~Year, random=~1|Field/Plant, data=strawberry,na.action=na.omit),
  lme(prop_damaged_beetle~Year, random=~1|Field/Plant, data=strawberry,na.action=na.omit),
  lme(prop_damaged_swd~Year+Field_Treatment_bin+Natural_25+Natural_5, random=~1|Field/Plant, data=strawberry,na.action=na.omit),
  lme(Prop_berries_market~Year+prop_damaged_lygus+PollinationRatio+Natural_5, data=strawberry, random=~1|Field/Plant,na.action=na.omit),
  lme(Total_berries~Year, data=strawberry, random=~1|Field/Plant,na.action=na.omit),
  prop_damaged_beetle%~~%prop_damaged_lygus, prop_damaged_beetle%~~%prop_damaged_swd, prop_damaged_swd%~~%prop_damaged_lygus,
  PollinationRatio%~~%prop_damaged_beetle, PollinationRatio%~~%prop_damaged_lygus, PollinationRatio%~~%prop_damaged_swd,
  Natural_25%~~%Natural_5, Natural_5%~~%Natural_1, Natural_25%~~%Natural_1,
  Total_berries%~~%Prop_berries_market
) 

summary(strw.mod)

#### Squash Path Model ####
squash.mod=psem(
  lme(Seeds_per_fruit_avg~Year+Natural_5+Natural_1, random=~1|Field/Plant, data=squash,na.action=na.omit),
  lme(prop_insect_damage~Year+Field_Treatment_bin*Natural_1, random=~1|Field/Plant, data=squash,na.action=na.omit),
  lme(Prop_squash_market~Year+Seeds_per_fruit_avg+prop_insect_damage+Natural_25, data=squash, random=~1|Field/Plant,na.action=na.omit),
  lme(Total_squash~Year, data=squash, random=~1|Field/Plant,na.action=na.omit),
  Prop_squash_market%~~%Total_squash, prop_insect_damage%~~%Seeds_per_fruit_avg,
  Natural_25%~~%Natural_5, Natural_5%~~%Natural_1, Natural_25%~~%Natural_1
)

summary(squash.mod)






